==> emberjs-build-0.1.2.tgz: package/lib/utils/transpile-es6.js <==
'use strict';

var esperanto = require('esperanto');
var map = require('broccoli-stew').map;
var babel = require('babel-core');

module.exports = function(tree, description, options) {
  if (!options) {
    options = {};
  }

  var transpiler;
  var moduleNames = {};
  var format = options.format || 'amd';

  if (format === 'cjs') {
    transpiler = esperanto.toCjs;
  } else if (format === 'umd') {
    transpiler = esperanto.toUmd;
  } else {
    transpiler = esperanto.toAmd;
  }

  var outputTree = map(tree, '**/*.js', function(content, relativePath) {
    var moduleName = moduleNames[relativePath];

    if (!moduleName) {
      moduleName = moduleNames[relativePath] = relativePath.slice(0, -3);
    }

    content = babel.transform(content, {
      filename: relativePath,
      loose: true,
      whitelist: [
        'es6.templateLiterals',
        'es6.parameters.rest',
        'es6.arrowFunctions',
        'es6.destructuring',
        'es6.spread',
        'es6.parameters.default',
        'es6.properties.computed',
        'es6.properties.shorthand',
        'es6.blockScoping',
        'es6.constants',
      ]
    }).code;

    return transpiler(content, {
      amdName: moduleName,
      strict: true,
      _evilES3SafeReExports: true
      //sourceMap: 'inline',
      //sourceMapSource: relativePath,
      //sourceMapFile: moduleName + '.map'
    }).code;

  });

  outputTree.description = 'ES6 Modules' + (description ? ': ' + description : '');

  return outputTree;
};

==> emberjs-build-0.1.3.tgz: package/lib/utils/transpile-es6.js <==
'use strict';

var esperanto = require('esperanto');
var map = require('broccoli-stew').map;
var babel = require('babel-core');
var Cache = require('sync-disk-cache');
var crypto = require('crypto');

var SHOULD_CACHE = process.env.DISK_CACHE;
var cache = new Cache('emberjs-build-es6');

if (process.env.PURGE_DISK_CACHE) {
  cache.clear();
}

module.exports = function(tree, description, options) {
  if (!options) {
    options = {};
  }

  var transpiler;
  var moduleNames = {};
  var format = options.format || 'amd';

  if (format === 'cjs') {
    transpiler = esperanto.toCjs;
  } else if (format === 'umd') {
    transpiler = esperanto.toUmd;
  } else {
    transpiler = esperanto.toAmd;
  }

  var outputTree = map(tree, '**/*.js', function(content, relativePath) {
    var moduleName = moduleNames[relativePath];

    if (!moduleName) {
      moduleName = moduleNames[relativePath] = relativePath.slice(0, -3);
    }

    var key;
    if (SHOULD_CACHE) {
      key = hash(content + 0x0 + moduleName);

      if (cache.has(key)) {
        return cache.get(key).value;
      }
    }

    content = babel.transform(content, {
      filename: relativePath,
      loose: true,
      whitelist: [
        'es6.templateLiterals',
        'es6.parameters.rest',
        'es6.arrowFunctions',
        'es6.destructuring',
        'es6.spread',
        'es6.parameters.default',
        'es6.properties.computed',
        'es6.properties.shorthand',
        'es6.blockScoping',
        'es6.constants',
      ]
    }).code;

    content = transpiler(content, {
      amdName: moduleName,
      strict: true,
      _evilES3SafeReExports: true
      //sourceMap: 'inline',
      //sourceMapSource: relativePath,
      //sourceMapFile: moduleName + '.map'
    }).code;

    if (SHOULD_CACHE) {
      cache.set(key, content);
    }
    return content;
  });

  outputTree.description = 'ES6 Modules' + (description ? ': ' + description : '');
  return outputTree;
};

function hash(string) {
  return crypto.createHash('md5').update(string).digest('hex');
}
